import java.awt.*;

/**
   This class builds a more visible point.
   @version 1.00 4 Dec 1997
   @author Octavian Cismasu
*/
public class BigPoint extends Point {
   public int size = 1;
   private boolean fill = false;
   
   /** 
      Constructs a new BigPoint object 
      with the specified size.
      @param s the size of the point in pixels
   */    
   public BigPoint(int s) {
      super();
      size = s;
   }
   
      
   /** 
      Constructs a new BigPoint object 
      at given x, y coordinates and with
      specified size.
      @param x the x coordinate
      @param y the y coordinate
      @param s the size of the point
   */   
   public BigPoint(int x, int y, int s) {
      super(x,y);
      size = s;
   }
   
   
   /**
      Sets the fill mode for a big point.
      A 'true' value fills the point, while
      a ' false' value will display an empty point.
      @param val the new fill mode value
   */   
   public void setFill(boolean val) {
      fill = val;
   }   
   
   
   /**
      Gets the current fill mode of this big point.
   */      
   public boolean getFill() {
      return this.fill;
   }   
   
   
   /**
      Gets the size value of this big point.
   */   
   public int getBpsize() {
      return this.size;
   }
          
   /**
      Displays this point on the given 
      graphics context.
      @param g the graphics context where this big point is to be displayed
   */   
   public void drawBigpoint(Graphics g) {
      if (!fill)      
         g.drawArc(this.x-(size/2), this.y-(size/2), size, size, 0, 360);
      else                
         g.fillArc(this.x-(size/2), this.y-(size/2), size, size, 0, 360);
   }      
}      
