import java.awt.*;

/**
   Class for displaying a message board.
   @version 1.00 4 Dec 1997
   @author Octavian Cismasu   
*/
public class MessageBoard extends Panel {
   private String message = " ";
   private Color color=Color.blue;
   private int font=Font.PLAIN;
   private TextField textf;
   private ResultCanvas rc;
   
   /**
      Constructs a new MessageBoard object.
   */      
   public MessageBoard() {
      //super();
     
      textf = new TextField(45);
      textf.setBackground(Color.yellow);
      textf.setFont(new Font("Helvetica", Font.PLAIN, 12));
      textf.setEditable(false);
      add(textf);
      
      rc = new ResultCanvas();
      rc.resize(85,25);
      add(rc);
   }         
          
   /**
      Sets the message to be displayed.
      @param txt the text of the message
   */
   public void setMessage(String txt, String res) {         
      textf.setText(txt);      
      if (res != "")
         rc.setResult(res);
      else
         rc.erase();         
   }     
}   




/** 
   Class for displaying a mesage in a Canvas
*/
class ResultCanvas extends Canvas {
   private String result="";
   private boolean eraseFlag=true; 
   
   /**
      Constructs a canvas with yellow background
   */
   public ResultCanvas() {
      super();
      setBackground(Color.yellow);
   }
   
   /**
      Displays the message in the current graphics context.
      @param g the graphics context
   */      
   public void paint(Graphics g) {      
      g.setColor(Color.red); 
      g.drawRect(0, 0, size().width-1, size().height-1);
      
      if (eraseFlag) {         
         g.clearRect(0, 0, size().width-1, size().height-1);
         eraseFlag = false;
      }   
      else {
         Font font = new Font("Helvetica", Font.PLAIN + Font.BOLD, 12);
         FontMetrics fm = g.getFontMetrics(font);
      
         g.setFont(font);
         g.drawString(result, (size().width - fm.stringWidth(result)) / 2,
            ((size().height - fm.getHeight()) / 2) + fm.getAscent());
      }         
   }   
  
   
   /**
      Sets the string to be displayed 
      @param r the result of the test (INSIDE or OUTSIDE)
   */   
   public void setResult(String r) {
      result = r;      
      repaint();
   }

   /** 
      Erases the result canvas area
   */
   public void erase() {
      eraseFlag = true;      
      result = "";
      repaint();
   }   
}      

